@@ -282,7 +282,7 @@ def img():
 @click.option("--all", "-a", is_flag=True, help="Show all images, including Pig standard images")
 def ls(all):  # noqa: F811
     """List all images"""
-    images = get_images()
+    images = asyncio.run(get_images())
     print_images(images, all)
 
 
